/*

	Class: AboutDialog
	Description: Dialog which provides information about the application and
				the author.
	Author: Roberto Virga

	All rights reserved. Permission to copy/use only upon previous
	notification to the author(s).

*/

package programs.games.minesweeper;

import java.awt.*;

final class AboutDialog extends Dialog {
	public AboutDialog(Frame parent) {

		super(parent,"About Minesweeper", true);

		setLayout(new BorderLayout());
		setFont(new Font("Dialog", Font.PLAIN, 11));
		setResizable(false);

		// Set up the dialog content

		Panel panel, subpanel;
		GridBagLayout layout;
		GridBagConstraints constraints;
		ImageComponent imageComponent;
		MultiLineLabel label;
		Button button;

		layout = new GridBagLayout();
		setLayout(layout);
		constraints = new GridBagConstraints();

		constraints.fill = GridBagConstraints.BOTH;
		constraints.insets = new Insets(10, 10, 10, 10);

		panel = new Panel();
		layout.setConstraints(panel, constraints);
		add(panel);
		panel.setLayout(new BorderLayout(10, 10));

		subpanel = new Panel();
		panel.add("Center", subpanel);

		layout = new GridBagLayout();
		subpanel.setLayout(layout);
		constraints = new GridBagConstraints();

		Image image = Toolkit.getDefaultToolkit().getImage("images/ms_icon.gif");
		MediaTracker tracker = new MediaTracker(this);

		tracker.addImage(image, 0);
		try {
			tracker.waitForID(0);
		} catch(InterruptedException e) {};

		constraints.anchor = GridBagConstraints.NORTHWEST;
		constraints.fill = GridBagConstraints.NONE;
		constraints.gridheight = GridBagConstraints.REMAINDER;

		imageComponent = new ImageComponent(image);
		layout.setConstraints(imageComponent, constraints);
		subpanel.add(imageComponent);

		constraints.anchor = GridBagConstraints.WEST;
		constraints.gridwidth = GridBagConstraints.REMAINDER;
		constraints.insets = new Insets(0, 20, 0, 50);

		label = new MultiLineLabel(
						"Minesweeper\n"
					  + "Pure JAVA\n"
					  + "Copyright \u00a9 1997 Roberto Virga\n"
					  + "Carnegie Mellon University\n"
					  + " \n"
					  + "Windows version by R. Donner and C. Johnson\n"
					  + "Copyright \u00a9 1981-1997 Microsoft Corporation",
					  MultiLineLabel.LEFT);
		layout.setConstraints(label, constraints);
		subpanel.add(label);

		// Add the dialog buttons

		subpanel = new Panel();
		panel.add("South", subpanel);

		layout = new GridBagLayout();
		subpanel.setLayout(layout);
		constraints = new GridBagConstraints();

		constraints.anchor = GridBagConstraints.EAST;
		constraints.weightx = 1.0;
		constraints.ipadx = 50;
		constraints.ipady = 2;

		button = new Button("OK");
		layout.setConstraints(button, constraints);
		subpanel.add(button);

		pack();

	}

	public boolean action(Event event, Object arg) {
		if ((event.target instanceof Button) && (arg == "OK")) {

			// Pressing OK closes the dialog

			hide();
			return true;
		} else
			return false;
	}

	public boolean handleEvent(Event event) {
		if (event.id == Event.WINDOW_DESTROY) {
			hide();
			return true;
		} else
			return super.handleEvent(event);
	}
}
