/*

	Class: BoardProperties
	Description: Object representing/storing the properties of the board.
	Author: Roberto Virga

	All rights reserved. Permission to copy/use only upon previous
	notification to the author(s).

*/

package programs.games.minesweeper;

class BoardProperties {
	private final static int MIN_ROWS = 8;		  // minimum and maximum legal values
	private final static int MAX_ROWS = 16;
	private final static int MIN_COLUMNS = 8;
	private final static int MAX_COLUMNS = 30;
	private final static int MIN_MINES = 10;
	private final static int MAX_MINES = 99;
	private final static int MAX_MINES_RATIO = 3;

	public int rows, columns, mines;

	public BoardProperties(int rows, int columns, int mines) {
		this.rows = rows;
		this.columns = columns;
		this.mines = mines;
	}

	public boolean equal(Object object) {
		if(object instanceof BoardProperties) {

			BoardProperties other = (BoardProperties) object;

			return(this.rows == other.rows &&
				   this.columns == other.columns &&
				   this.mines == other.mines);
		} else
			return false;
	}

	public void validate() {
		rows = Math.max(rows, MIN_ROWS);
		rows = Math.min(rows, MAX_ROWS);

		columns = Math.max(columns, MIN_COLUMNS);
		columns = Math.min(columns, MAX_COLUMNS);

		mines = Math.min(mines, (rows*columns)/MAX_MINES_RATIO);
		mines = Math.max(mines, MIN_MINES);
		mines = Math.min(mines, MAX_MINES);
	}

	public static BoardProperties getMinProperties() {
		return(new BoardProperties(MIN_ROWS, MIN_COLUMNS, MIN_MINES));
	}

	public static BoardProperties getMaxProperties() {
		return(new BoardProperties(MAX_ROWS, MAX_COLUMNS, MAX_MINES));
	}
}
