/*

	Class: ImageComponent
	Description: Component visualizing a picture.
	Author: Roberto Virga

	All rights reserved. Permission to copy/use only upon previous
	notification to the author(s).

*/

package programs.games.minesweeper;

import java.awt.*;

public class ImageComponent extends Canvas {
	private Image image;

	public ImageComponent(Image image) {
		this.image = image;
	}

	public ImageComponent() {
		this(null);
	}

	public Image getImage() {
		return image;
	}

	public void setImage(Image image) {
		this.image = image;
		repaint();
	}

	public void paint(Graphics g) {
	    update(g);
	}

	public void update(Graphics g) {

		Dimension size = size();

		// Draws the image centered

		int x = (size.width - image.getWidth(this))/2;
		int y = (size.height - image.getHeight(this))/2;

		g.drawImage(image, x, y, this);
	}

	public Dimension preferredSize() {

		int w = (image == null) ? 0 : image.getWidth(this);
		int h = (image == null) ? 0 : image.getHeight(this);

 		return(new Dimension(w, h));
	}

	public Dimension minimumSize() {

		int w = (image == null) ? 0 : image.getWidth(this);
		int h = (image == null) ? 0 : image.getHeight(this);

 		return(new Dimension(w, h));
	}
}
