/*

	Class: NewBestTimeDialog
	Description: Dialog to insert a new name to the highest scores list.
	Author: Roberto Virga

	All rights reserved. Permission to copy/use only upon previous
	notification to the author(s).

*/

package programs.games.minesweeper;

import java.awt.*;

final class NewBestTimeDialog extends Dialog {
	private final static String TYPE[] =
		{"beginner", "intermediate", "expert"};

	private int user, time;

	private MultiLineLabel userLabel;
	private TextField nameField;
	private BestTimesDialog bestTimesDialog;

	public NewBestTimeDialog(Frame parent, BestTimesDialog bestTimesDialog) {

		super(parent, "Congratulations", true);

		this.bestTimesDialog = bestTimesDialog;
		user = time = 0;


		setLayout(new BorderLayout());
		setFont(new Font("Dialog", Font.PLAIN, 11));
		setResizable(false);

		// Set up the dialog content

		Panel panel, subpanel;
		GridBagLayout layout;
		GridBagConstraints constraints;
		Button button;

		layout = new GridBagLayout();
		setLayout(layout);
		constraints = new GridBagConstraints();

		constraints.fill = GridBagConstraints.BOTH;
		constraints.insets = new Insets(10, 10, 10, 10);
		constraints.weightx = 1.0;
		constraints.weighty = 1.0;

		panel = new Panel();
		layout.setConstraints(panel, constraints);
		add(panel);
		panel.setLayout(new BorderLayout(10, 10));

		subpanel = new Panel();
		panel.add("Center", subpanel);

		layout = new GridBagLayout();
		subpanel.setLayout(layout);
		constraints = new GridBagConstraints();

		constraints.anchor = GridBagConstraints.WEST;
		constraints.gridwidth = GridBagConstraints.REMAINDER;
		constraints.fill = GridBagConstraints.HORIZONTAL;
		constraints.weightx = 1.0;

		userLabel = new MultiLineLabel("", 0, 0, MultiLineLabel.LEFT);
		layout.setConstraints(userLabel, constraints);
		subpanel.add(userLabel);

		constraints.insets = new Insets(5, 0, 0, 0);

		nameField = new TextField("", 30);
		layout.setConstraints(nameField, constraints);
		subpanel.add(nameField);

		// Add the dialog buttons

		subpanel = new Panel();
		panel.add("South", subpanel);

		layout = new GridBagLayout();
		subpanel.setLayout(layout);
		constraints = new GridBagConstraints();

		constraints = new GridBagConstraints();

		constraints.anchor = GridBagConstraints.SOUTHEAST;
		constraints.weightx = 1.0;
		constraints.ipadx = 50;
		constraints.ipady = 2;

		button = new Button("OK");
		layout.setConstraints(button, constraints);
		subpanel.add(button);

		pack();
	}

	public void show(int user, int time, String name) {

		// If the user is not of a known type, do nothing

		if((user < 0) || (user >= TYPE.length))
			return;

		this.user = user;
		this.time = time;

		// Change the relevant dialog components and make sure they're repainted

		userLabel.setLabel(
			"You have the fastest time for " + TYPE[user] + "\n"
			+ "level. Please type your name:");
		nameField.setText(name);
		userLabel.invalidate();
		nameField.invalidate();

		pack();
		show();
	}

	public boolean action(Event event, Object arg) {
		if (event.target instanceof Button && arg == "OK") {

			// Send the data to the high score manager

			bestTimesDialog.setTime(user, time, nameField.getText());
			hide();
			bestTimesDialog.show();
			return true;
		} else
			return false;
	}

	public boolean handleEvent(Event event) {
		if (event.id == Event.WINDOW_DESTROY) {

			// Send the data to the high score manager

			hide();
			bestTimesDialog.setTime(user, time, nameField.getText());
			bestTimesDialog.show();
			return true;
		} else
			return super.handleEvent(event);
	}
}
