/*

	Class: Panel3D
	Description: Panel with a 3D border.
	Author: Roberto Virga

	All rights reserved. Permission to copy/use only upon previous
	notification to the author(s).

*/

package programs.games.minesweeper;

import java.awt.*;

public class Panel3D extends Panel implements MultipleColorModes {
	private int border;		 // size of the 3D border
	private boolean raised;
	private int color_mode;

	public Panel3D(int border, boolean raised, int color_mode) {
		this.border = border;
		this.raised = raised;
		this.color_mode = color_mode;
	}

	public Panel3D(int border, boolean raised) {
		this(border, raised, MODE_BW);
	}

	public int getColorMode() {
		return color_mode;
	}

	public void setColorMode(int mode) {

		// First pass the message to all the components it contains

		Component component[] = getComponents();

		int i;

		for(i = 0; i < component.length; i++)
			if(component[i] instanceof MultipleColorModes)
				((MultipleColorModes) component[i]).setColorMode(mode);

		// Then redraw yourself accordingly

		if(mode != color_mode) {
			color_mode = mode;
			repaint();
		}
	}

	public Insets insets() {
		return new Insets(border, border, border, border);
	}

	public void paint(Graphics g) {
	    update(g);
	}

	public void update(Graphics g) {

		Color background, top_left, bottom_right;

		switch(color_mode) {
			case MODE_BW:
				background = Color.lightGray;
				top_left = Color.black;
				bottom_right = Color.white;
				break;
			default:
				background = getBackground();
				top_left = background.darker();
				bottom_right = background.brighter();
				break;
		}

		if(raised) {
			Color temp = top_left;
			top_left = bottom_right;
			bottom_right = temp;
		}

		Dimension size = size();

		int i;

		for(i = 0; i < border; i++) {
			g.setColor(top_left);
			g.drawLine(i, i, i, i + (size.height-2*i));
			g.drawLine(i, i, i + (size.width-2*i), i);
			g.setColor(bottom_right);
			g.drawLine(i, i + (size.height-2*i), i + (size.width-2*i), i + (size.height-2*i));
			g.drawLine(i + (size.width-2*i), i, i + (size.width-2*i), i + (size.height-2*i));
		}

		g.setColor(background);
		g.fillRect(i, i, size.width-2*i, size.height-2*i);
	}
}
